@@ -1,15 +1,10 @@
 import asyncio
 
-from change_detector import ChangeDetector
-
 
 class Watcher:
-    def __init__(self, directories, ignores, command):
-        self._directories = directories
-        self._ignores = ignores
+    def __init__(self, change_detector, command):
+        self._change_detector = change_detector
         self._command = command
-
-        self._change_q = asyncio.Queue(maxsize=-1)
         self._process = None
 
     async def _create_process(self):
@@ -29,11 +24,10 @@ class Watcher:
             print(line)
 
     async def run(self):
-        change_detector = ChangeDetector(self._change_q)
-        asyncio.create_task(change_detector.run(self._directories, self._ignores))
+        asyncio.create_task(self._change_detector.run())
 
         while True:
-            await self._change_q.get()
+            await self._change_detector.queue.get()
             if self._process:
                 try:
                     self._process.terminate()
